
Changelog
---------

0.6
~~~

- Adds detail view with configurable positioning through schema attributes.
  [href]

- Fixes not showing the selected filter after a refresh.
  [href]

0.5
~~~

- Supports supermodel security permissions in the people's list (giving the
  ability to hide certain fields in the table depending on the user).
  [href]

- Fixes filter.js being unable to filter for empty values.
  [href]

0.4
~~~

- Ensures that the title is updated when the object is modified.
  [href]

- The first letters are now taken from the sorted title.
  [href]

- The title attributes order is now independent of the field order.
  [href]

- Fixes a number of unicode issues.
  [href]

0.3
~~~

(skipped by accident)

0.2
~~~

- People are now sorted by unicode collation.
  [href]

- The people can be filtered by the first litter of the title.
  [href]

0.1
~~~

- Initial release.
  [href]
